==> allennlp-0.9.1.dev20200221.tar.gz: allennlp-0.9.1.dev20200221/tutorials/README.md <==
# Tutorials

**If you're just starting, please check out [the tutorial on our website](https://allennlp.org/tutorials). We've designed it to be the simplest and quickest way to get your toes wet with AllenNLP.**

Our 2018 EMNLP tutorial is available at https://github.com/allenai/writing-code-for-nlp-research-emnlp2018.

## Tutorials Have Moved!

Our tutorials now live in the [docs directory](../docs/tutorials). You can view them via our [docs website](https://allenai.github.io/allennlp-docs/). This directory now only contains the introductory, interactive tagging tutorial present on our main website, [allennlp.org](https://allennlp.org/).

## Internal Tutorials

The tutorials available here on the repo relate to the version of AllenNLP at the git commit SHA you are currently looking at (likely the HEAD commit of the master branch).  If you want to see the tutorial sources that relate to the latest pip release, please see https://github.com/allenai/allennlp/tree/v0.8.3/tutorials.

### Getting Started

* [Installation](../README.md#installation)

## External Tutorials

* The [blog posts by Masato Hagiwara](http://www.realworldnlpbook.com/blog/) as he writes his NLP book
* [An in-depth tutorial by Keita Kurita](https://mlexplained.com/2019/01/30/an-in-depth-tutorial-to-allennlp-from-basics-to-elmo-and-bert/)
* [Ethan Chau's extended Getting Started guide](https://gitlab.cs.washington.edu/echau18/tech-writing-mirror/blob/master/the-annotated-config/the-annotated-config.md)
* The [blog posts by Joe Barrow](https://jbarrow.ai/)

==> allennlp-1.0.0rc4.dev20200507.tar.gz: allennlp-1.0.0rc4.dev20200507/tutorials/README.md <==
# Tutorials

**If you're just starting, please check out [the tutorial on our website](https://allennlp.org/tutorials). We've designed it to be the simplest and quickest way to get your toes wet with AllenNLP.**

Our 2018 EMNLP tutorial is available at https://github.com/allenai/writing-code-for-nlp-research-emnlp2018.

## Tutorials Have Moved!

Our tutorials now live in the [docs directory](../docs/tutorials). You can view them via our [docs website](https://docs.allennlp.org/master/). This directory now only contains the introductory, interactive tagging tutorial present on our main website, [allennlp.org](https://allennlp.org/).

## Internal Tutorials

The tutorials available here on the repo relate to the version of AllenNLP at the git commit SHA you are currently looking at (likely the HEAD commit of the master branch).  If you want to see the tutorial sources that relate to the latest pip release, please see https://github.com/allenai/allennlp/tree/v0.8.3/tutorials.

### Getting Started

* [Installation](../README.md#installation)

## External Tutorials

* The [blog posts by Masato Hagiwara](http://www.realworldnlpbook.com/blog/) as he writes his NLP book
* [An in-depth tutorial by Keita Kurita](https://mlexplained.com/2019/01/30/an-in-depth-tutorial-to-allennlp-from-basics-to-elmo-and-bert/)
* [Ethan Chau's extended Getting Started guide](https://gitlab.cs.washington.edu/echau18/tech-writing-mirror/blob/master/the-annotated-config/the-annotated-config.md)
* The [blog posts by Joe Barrow](https://jbarrow.ai/)
